module Text.Numerals.Languages.DutchSpec (
    spec
  ) where

import Data.Text(Text)

import Test.Hspec(Spec)
import Text.Numerals.Languages.Dutch(dutch)
import Text.Numerals.LanguageTest(testLanguage)

spec :: Spec
spec = testLanguage "Dutch" dutch cardinals ordinals

cardinals :: [(Integer, Text)]
cardinals = [
    (0, "nul")
  , (1, "één")
  , (2, "twee")
  , (3, "drie")
  , (4, "vier")
  , (5, "vijf")
  , (6, "zes")
  , (7, "zeven")
  , (8, "acht")
  , (9, "negen")
  , (10, "tien")
  , (11, "elf")
  , (12, "twaalf")
  , (13, "dertien")
  , (14, "veertien")
  , (15, "vijftien")
  , (16, "zestien")
  , (17, "zeventien")
  , (18, "achttien")
  , (19, "negentien")
  , (20, "twintig")
  , (21, "eenentwintig")
  , (22, "tweeëntwintig")
  , (23, "drieëntwintig")
  , (24, "vierentwintig")
  , (25, "vijfentwintig")
  , (26, "zesentwintig")
  , (27, "zevenentwintig")
  , (28, "achtentwintig")
  , (29, "negenentwintig")
  , (30, "dertig")
  , (31, "eenendertig")
  , (32, "tweeëndertig")
  , (33, "drieëndertig")
  , (34, "vierendertig")
  , (35, "vijfendertig")
  , (36, "zesendertig")
  , (37, "zevenendertig")
  , (38, "achtendertig")
  , (39, "negenendertig")
  , (40, "veertig")
  , (41, "eenenveertig")
  , (42, "tweeënveertig")
  , (43, "drieënveertig")
  , (44, "vierenveertig")
  , (45, "vijfenveertig")
  , (46, "zesenveertig")
  , (47, "zevenenveertig")
  , (48, "achtenveertig")
  , (49, "negenenveertig")
  , (50, "vijftig")
  , (51, "eenenvijftig")
  , (52, "tweeënvijftig")
  , (53, "drieënvijftig")
  , (54, "vierenvijftig")
  , (55, "vijfenvijftig")
  , (56, "zesenvijftig")
  , (57, "zevenenvijftig")
  , (58, "achtenvijftig")
  , (59, "negenenvijftig")
  , (60, "zestig")
  , (61, "eenenzestig")
  , (62, "tweeënzestig")
  , (63, "drieënzestig")
  , (64, "vierenzestig")
  , (65, "vijfenzestig")
  , (66, "zesenzestig")
  , (67, "zevenenzestig")
  , (68, "achtenzestig")
  , (69, "negenenzestig")
  , (70, "zeventig")
  , (71, "eenenzeventig")
  , (72, "tweeënzeventig")
  , (73, "drieënzeventig")
  , (74, "vierenzeventig")
  , (75, "vijfenzeventig")
  , (76, "zesenzeventig")
  , (77, "zevenenzeventig")
  , (78, "achtenzeventig")
  , (79, "negenenzeventig")
  , (80, "tachtig")
  , (81, "eenentachtig")
  , (82, "tweeëntachtig")
  , (83, "drieëntachtig")
  , (84, "vierentachtig")
  , (85, "vijfentachtig")
  , (86, "zesentachtig")
  , (87, "zevenentachtig")
  , (88, "achtentachtig")
  , (89, "negenentachtig")
  , (90, "negentig")
  , (91, "eenennegentig")
  , (92, "tweeënnegentig")
  , (93, "drieënnegentig")
  , (94, "vierennegentig")
  , (95, "vijfennegentig")
  , (96, "zesennegentig")
  , (97, "zevenennegentig")
  , (98, "achtennegentig")
  , (99, "negenennegentig")
  , (100, "honderd")
  , (101, "honderdéén")
  , (102, "honderdtwee")
  , (103, "honderddrie")
  , (104, "honderdvier")
  , (105, "honderdvijf")
  , (106, "honderdzes")
  , (107, "honderdzeven")
  , (108, "honderdacht")
  , (109, "honderdnegen")
  , (110, "honderdtien")
  , (111, "honderdelf")
  , (112, "honderdtwaalf")
  , (113, "honderddertien")
  , (114, "honderdveertien")
  , (115, "honderdvijftien")
  , (116, "honderdzestien")
  , (117, "honderdzeventien")
  , (118, "honderdachttien")
  , (119, "honderdnegentien")
  , (120, "honderdtwintig")
  , (121, "honderdeenentwintig")
  , (122, "honderdtweeëntwintig")
  , (123, "honderddrieëntwintig")
  , (124, "honderdvierentwintig")
  , (125, "honderdvijfentwintig")
  , (126, "honderdzesentwintig")
  , (127, "honderdzevenentwintig")
  , (128, "honderdachtentwintig")
  , (129, "honderdnegenentwintig")
  , (130, "honderddertig")
  , (131, "honderdeenendertig")
  , (132, "honderdtweeëndertig")
  , (133, "honderddrieëndertig")
  , (134, "honderdvierendertig")
  , (135, "honderdvijfendertig")
  , (136, "honderdzesendertig")
  , (137, "honderdzevenendertig")
  , (138, "honderdachtendertig")
  , (139, "honderdnegenendertig")
  , (140, "honderdveertig")
  , (141, "honderdeenenveertig")
  , (142, "honderdtweeënveertig")
  , (143, "honderddrieënveertig")
  , (144, "honderdvierenveertig")
  , (145, "honderdvijfenveertig")
  , (146, "honderdzesenveertig")
  , (147, "honderdzevenenveertig")
  , (148, "honderdachtenveertig")
  , (149, "honderdnegenenveertig")
  , (150, "honderdvijftig")
  , (151, "honderdeenenvijftig")
  , (152, "honderdtweeënvijftig")
  , (153, "honderddrieënvijftig")
  , (154, "honderdvierenvijftig")
  , (155, "honderdvijfenvijftig")
  , (156, "honderdzesenvijftig")
  , (157, "honderdzevenenvijftig")
  , (158, "honderdachtenvijftig")
  , (159, "honderdnegenenvijftig")
  , (160, "honderdzestig")
  , (161, "honderdeenenzestig")
  , (162, "honderdtweeënzestig")
  , (163, "honderddrieënzestig")
  , (164, "honderdvierenzestig")
  , (165, "honderdvijfenzestig")
  , (166, "honderdzesenzestig")
  , (167, "honderdzevenenzestig")
  , (168, "honderdachtenzestig")
  , (169, "honderdnegenenzestig")
  , (170, "honderdzeventig")
  , (171, "honderdeenenzeventig")
  , (172, "honderdtweeënzeventig")
  , (173, "honderddrieënzeventig")
  , (174, "honderdvierenzeventig")
  , (175, "honderdvijfenzeventig")
  , (176, "honderdzesenzeventig")
  , (177, "honderdzevenenzeventig")
  , (178, "honderdachtenzeventig")
  , (179, "honderdnegenenzeventig")
  , (180, "honderdtachtig")
  , (181, "honderdeenentachtig")
  , (182, "honderdtweeëntachtig")
  , (183, "honderddrieëntachtig")
  , (184, "honderdvierentachtig")
  , (185, "honderdvijfentachtig")
  , (186, "honderdzesentachtig")
  , (187, "honderdzevenentachtig")
  , (188, "honderdachtentachtig")
  , (189, "honderdnegenentachtig")
  , (190, "honderdnegentig")
  , (191, "honderdeenennegentig")
  , (192, "honderdtweeënnegentig")
  , (193, "honderddrieënnegentig")
  , (194, "honderdvierennegentig")
  , (195, "honderdvijfennegentig")
  , (196, "honderdzesennegentig")
  , (197, "honderdzevenennegentig")
  , (198, "honderdachtennegentig")
  , (199, "honderdnegenennegentig")
  , (200, "tweehonderd")
  , (233, "tweehonderddrieëndertig")
  , (377, "driehonderdzevenenzeventig")
  , (610, "zeshonderdtien")
  , (987, "negenhonderdzevenentachtig")
  , (1597, "duizendvijfhonderdzevenennegentig")
  , (2584, "tweeduizendvijfhonderdvierentachtig")
  , (4181, "vierduizendhonderdeenentachtig")
  , (6765, "zesduizendzevenhonderdvijfenzestig")
  , (10946, "tienduizendnegenhonderdzesenveertig")
  , (17711, "zeventienduizendzevenhonderdelf")
  , (28657, "achtentwintigduizendzeshonderdzevenenvijftig")
  , (46368, "zesenveertigduizenddriehonderdachtenzestig")
  , (75025, "vijfenzeventigduizendvijfentwintig")
  , (121393, "honderdeenentwintigduizenddriehonderddrieënnegentig")
  , (196418, "honderdzesennegentigduizendvierhonderdachttien")
  , (317811, "driehonderdzeventienduizendachthonderdelf")
  , (514229, "vijfhonderdveertienduizendtweehonderdnegenentwintig")
  , (832040, "achthonderdtweeëndertigduizendveertig")
  , (1346269, "een miljoen driehonderdzesenveertigduizendtweehonderdnegenenzestig")
  , (2178309, "twee miljoen honderdachtenzeventigduizenddriehonderdnegen")
  , (3524578, "drie miljoen vijfhonderdvierentwintigduizendvijfhonderdachtenzeventig")
  , (5702887, "vijf miljoen zevenhonderdtweeduizendachthonderdzevenentachtig")
  , (9227465, "negen miljoen tweehonderdzevenentwintigduizendvierhonderdvijfenzestig")
  , (14930352, "veertien miljoen negenhonderddertigduizenddriehonderdtweeënvijftig")
  , (24157817, "vierentwintig miljoen honderdzevenenvijftigduizendachthonderdzeventien")
  , (39088169, "negenendertig miljoen achtentachtigduizendhonderdnegenenzestig")
  , (63245986, "drieënzestig miljoen tweehonderdvijfenveertigduizendnegenhonderdzesentachtig")
  , (102334155, "honderdtwee miljoen driehonderdvierendertigduizendhonderdvijfenvijftig")
  , (165580141, "honderdvijfenzestig miljoen vijfhonderdtachtigduizendhonderdeenenveertig")
  , (267914296, "tweehonderdzevenenzestig miljoen negenhonderdveertienduizendtweehonderdzesennegentig")
  , (433494437, "vierhonderddrieëndertig miljoen vierhonderdvierennegentigduizendvierhonderdzevenendertig")
  , (701408733, "zevenhonderdéén miljoen vierhonderdachtduizendzevenhonderddrieëndertig")
  , (1134903170, "een miljard honderdvierendertig miljoen negenhonderddrieduizendhonderdzeventig")
  , (1836311903, "een miljard achthonderdzesendertig miljoen driehonderdelfduizendnegenhonderddrie")
  , (2971215073, "twee miljard negenhonderdeenenzeventig miljoen tweehonderdvijftienduizenddrieënzeventig")
  , (4807526976, "vier miljard achthonderdzeven miljoen vijfhonderdzesentwintigduizendnegenhonderdzesenzeventig")
  , (7778742049, "zeven miljard zevenhonderdachtenzeventig miljoen zevenhonderdtweeënveertigduizendnegenenveertig")
  , (12586269025, "twaalf miljard vijfhonderdzesentachtig miljoen tweehonderdnegenenzestigduizendvijfentwintig")
  , (20365011074, "twintig miljard driehonderdvijfenzestig miljoen elfduizendvierenzeventig")
  , (32951280099, "tweeëndertig miljard negenhonderdeenenvijftig miljoen tweehonderdtachtigduizendnegenennegentig")
  , (53316291173, "drieënvijftig miljard driehonderdzestien miljoen tweehonderdeenennegentigduizendhonderddrieënzeventig")
  , (86267571272, "zesentachtig miljard tweehonderdzevenenzestig miljoen vijfhonderdeenenzeventigduizendtweehonderdtweeënzeventig")
  , (139583862445, "honderdnegenendertig miljard vijfhonderddrieëntachtig miljoen achthonderdtweeënzestigduizendvierhonderdvijfenveertig")
  , (225851433717, "tweehonderdvijfentwintig miljard achthonderdeenenvijftig miljoen vierhonderddrieëndertigduizendzevenhonderdzeventien")
  , (365435296162, "driehonderdvijfenzestig miljard vierhonderdvijfendertig miljoen tweehonderdzesennegentigduizendhonderdtweeënzestig")
  , (591286729879, "vijfhonderdeenennegentig miljard tweehonderdzesentachtig miljoen zevenhonderdnegenentwintigduizendachthonderdnegenenzeventig")
  , (956722026041, "negenhonderdzesenvijftig miljard zevenhonderdtweeëntwintig miljoen zesentwintigduizendeenenveertig")
  , (1548008755920, "een biljoen vijfhonderdachtenveertig miljard acht miljoen zevenhonderdvijfenvijftigduizendnegenhonderdtwintig")
  , (2504730781961, "twee biljoen vijfhonderdvier miljard zevenhonderddertig miljoen zevenhonderdeenentachtigduizendnegenhonderdeenenzestig")
  , (4052739537881, "vier biljoen tweeënvijftig miljard zevenhonderdnegenendertig miljoen vijfhonderdzevenendertigduizendachthonderdeenentachtig")
  , (6557470319842, "zes biljoen vijfhonderdzevenenvijftig miljard vierhonderdzeventig miljoen driehonderdnegentienduizendachthonderdtweeënveertig")
  , (10610209857723, "tien biljoen zeshonderdtien miljard tweehonderdnegen miljoen achthonderdzevenenvijftigduizendzevenhonderddrieëntwintig")
  , (17167680177565, "zeventien biljoen honderdzevenenzestig miljard zeshonderdtachtig miljoen honderdzevenenzeventigduizendvijfhonderdvijfenzestig")
  , (27777890035288, "zevenentwintig biljoen zevenhonderdzevenenzeventig miljard achthonderdnegentig miljoen vijfendertigduizendtweehonderdachtentachtig")
  , (44945570212853, "vierenveertig biljoen negenhonderdvijfenveertig miljard vijfhonderdzeventig miljoen tweehonderdtwaalfduizendachthonderddrieënvijftig")
  , (72723460248141, "tweeënzeventig biljoen zevenhonderddrieëntwintig miljard vierhonderdzestig miljoen tweehonderdachtenveertigduizendhonderdeenenveertig")
  , (117669030460994, "honderdzeventien biljoen zeshonderdnegenenzestig miljard dertig miljoen vierhonderdzestigduizendnegenhonderdvierennegentig")
  , (190392490709135, "honderdnegentig biljoen driehonderdtweeënnegentig miljard vierhonderdnegentig miljoen zevenhonderdnegenduizendhonderdvijfendertig")
  , (308061521170129, "driehonderdacht biljoen eenenzestig miljard vijfhonderdeenentwintig miljoen honderdzeventigduizendhonderdnegenentwintig")
  , (498454011879264, "vierhonderdachtennegentig biljoen vierhonderdvierenvijftig miljard elf miljoen achthonderdnegenenzeventigduizendtweehonderdvierenzestig")
  , (806515533049393, "achthonderdzes biljoen vijfhonderdvijftien miljard vijfhonderddrieëndertig miljoen negenenveertigduizenddriehonderddrieënnegentig")
  , (1304969544928657, "een biljard driehonderdvier biljoen negenhonderdnegenenzestig miljard vijfhonderdvierenveertig miljoen negenhonderdachtentwintigduizendzeshonderdzevenenvijftig")
  , (2111485077978050, "twee biljard honderdelf biljoen vierhonderdvijfentachtig miljard zevenenzeventig miljoen negenhonderdachtenzeventigduizendvijftig")
  , (3416454622906707, "drie biljard vierhonderdzestien biljoen vierhonderdvierenvijftig miljard zeshonderdtweeëntwintig miljoen negenhonderdzesduizendzevenhonderdzeven")
  , (5527939700884757, "vijf biljard vijfhonderdzevenentwintig biljoen negenhonderdnegenendertig miljard zevenhonderd miljoen achthonderdvierentachtigduizendzevenhonderdzevenenvijftig")
  , (8944394323791464, "acht biljard negenhonderdvierenveertig biljoen driehonderdvierennegentig miljard driehonderddrieëntwintig miljoen zevenhonderdeenennegentigduizendvierhonderdvierenzestig")
  , (14472334024676221, "veertien biljard vierhonderdtweeënzeventig biljoen driehonderdvierendertig miljard vierentwintig miljoen zeshonderdzesenzeventigduizendtweehonderdeenentwintig")
  , (23416728348467685, "drieëntwintig biljard vierhonderdzestien biljoen zevenhonderdachtentwintig miljard driehonderdachtenveertig miljoen vierhonderdzevenenzestigduizendzeshonderdvijfentachtig")
  , (37889062373143906, "zevenendertig biljard achthonderdnegenentachtig biljoen tweeënzestig miljard driehonderddrieënzeventig miljoen honderddrieënveertigduizendnegenhonderdzes")
  , (61305790721611591, "eenenzestig biljard driehonderdvijf biljoen zevenhonderdnegentig miljard zevenhonderdeenentwintig miljoen zeshonderdelfduizendvijfhonderdeenennegentig")
  , (99194853094755497, "negenennegentig biljard honderdvierennegentig biljoen achthonderddrieënvijftig miljard vierennegentig miljoen zevenhonderdvijfenvijftigduizendvierhonderdzevenennegentig")
  , (160500643816367088, "honderdzestig biljard vijfhonderd biljoen zeshonderddrieënveertig miljard achthonderdzestien miljoen driehonderdzevenenzestigduizendachtentachtig")
  , (259695496911122585, "tweehonderdnegenenvijftig biljard zeshonderdvijfennegentig biljoen vierhonderdzesennegentig miljard negenhonderdelf miljoen honderdtweeëntwintigduizendvijfhonderdvijfentachtig")
  , (420196140727489673, "vierhonderdtwintig biljard honderdzesennegentig biljoen honderdveertig miljard zevenhonderdzevenentwintig miljoen vierhonderdnegenentachtigduizendzeshonderddrieënzeventig")
  , (679891637638612258, "zeshonderdnegenenzeventig biljard achthonderdeenennegentig biljoen zeshonderdzevenendertig miljard zeshonderdachtendertig miljoen zeshonderdtwaalfduizendtweehonderdachtenvijftig")
  , (1100087778366101931, "een triljoen honderd biljard zevenentachtig biljoen zevenhonderdachtenzeventig miljard driehonderdzesenzestig miljoen honderdéénduizendnegenhonderdeenendertig")
  , (1779979416004714189, "een triljoen zevenhonderdnegenenzeventig biljard negenhonderdnegenenzeventig biljoen vierhonderdzestien miljard vier miljoen zevenhonderdveertienduizendhonderdnegenentachtig")
  , (2880067194370816120, "twee triljoen achthonderdtachtig biljard zevenenzestig biljoen honderdvierennegentig miljard driehonderdzeventig miljoen achthonderdzestienduizendhonderdtwintig")
  , (4660046610375530309, "vier triljoen zeshonderdzestig biljard zesenveertig biljoen zeshonderdtien miljard driehonderdvijfenzeventig miljoen vijfhonderddertigduizenddriehonderdnegen")
  , (7540113804746346429, "zeven triljoen vijfhonderdveertig biljard honderddertien biljoen achthonderdvier miljard zevenhonderdzesenveertig miljoen driehonderdzesenveertigduizendvierhonderdnegenentwintig")
  , (12200160415121876738, "twaalf triljoen tweehonderd biljard honderdzestig biljoen vierhonderdvijftien miljard honderdeenentwintig miljoen achthonderdzesenzeventigduizendzevenhonderdachtendertig")
  , (19740274219868223167, "negentien triljoen zevenhonderdveertig biljard tweehonderdvierenzeventig biljoen tweehonderdnegentien miljard achthonderdachtenzestig miljoen tweehonderddrieëntwintigduizendhonderdzevenenzestig")
  , (31940434634990099905, "eenendertig triljoen negenhonderdveertig biljard vierhonderdvierendertig biljoen zeshonderdvierendertig miljard negenhonderdnegentig miljoen negenennegentigduizendnegenhonderdvijf")
  , (51680708854858323072, "eenenvijftig triljoen zeshonderdtachtig biljard zevenhonderdacht biljoen achthonderdvierenvijftig miljard achthonderdachtenvijftig miljoen driehonderddrieëntwintigduizendtweeënzeventig")
  , (83621143489848422977, "drieëntachtig triljoen zeshonderdeenentwintig biljard honderddrieënveertig biljoen vierhonderdnegenentachtig miljard achthonderdachtenveertig miljoen vierhonderdtweeëntwintigduizendnegenhonderdzevenenzeventig")
  , (135301852344706746049, "honderdvijfendertig triljoen driehonderdéén biljard achthonderdtweeënvijftig biljoen driehonderdvierenveertig miljard zevenhonderdzes miljoen zevenhonderdzesenveertigduizendnegenenveertig")
  , (218922995834555169026, "tweehonderdachttien triljoen negenhonderdtweeëntwintig biljard negenhonderdvijfennegentig biljoen achthonderdvierendertig miljard vijfhonderdvijfenvijftig miljoen honderdnegenenzestigduizendzesentwintig")
  , (354224848179261915075, "driehonderdvierenvijftig triljoen tweehonderdvierentwintig biljard achthonderdachtenveertig biljoen honderdnegenenzeventig miljard tweehonderdeenenzestig miljoen negenhonderdvijftienduizendvijfenzeventig")
  , (573147844013817084101, "vijfhonderddrieënzeventig triljoen honderdzevenenveertig biljard achthonderdvierenveertig biljoen dertien miljard achthonderdzeventien miljoen vierentachtigduizendhonderdéén")
  , (927372692193078999176, "negenhonderdzevenentwintig triljoen driehonderdtweeënzeventig biljard zeshonderdtweeënnegentig biljoen honderddrieënnegentig miljard achtenzeventig miljoen negenhonderdnegenennegentigduizendhonderdzesenzeventig")
  , (1500520536206896083277, "een triljard vijfhonderd triljoen vijfhonderdtwintig biljard vijfhonderdzesendertig biljoen tweehonderdzes miljard achthonderdzesennegentig miljoen drieëntachtigduizendtweehonderdzevenenzeventig")
  , (2427893228399975082453, "twee triljard vierhonderdzevenentwintig triljoen achthonderddrieënnegentig biljard tweehonderdachtentwintig biljoen driehonderdnegenennegentig miljard negenhonderdvijfenzeventig miljoen tweeëntachtigduizendvierhonderddrieënvijftig")
  , (3928413764606871165730, "drie triljard negenhonderdachtentwintig triljoen vierhonderddertien biljard zevenhonderdvierenzestig biljoen zeshonderdzes miljard achthonderdeenenzeventig miljoen honderdvijfenzestigduizendzevenhonderddertig")
  , (6356306993006846248183, "zes triljard driehonderdzesenvijftig triljoen driehonderdzes biljard negenhonderddrieënnegentig biljoen zes miljard achthonderdzesenveertig miljoen tweehonderdachtenveertigduizendhonderddrieëntachtig")
  , (10284720757613717413913, "tien triljard tweehonderdvierentachtig triljoen zevenhonderdtwintig biljard zevenhonderdzevenenvijftig biljoen zeshonderddertien miljard zevenhonderdzeventien miljoen vierhonderddertienduizendnegenhonderddertien")
  , (16641027750620563662096, "zestien triljard zeshonderdeenenveertig triljoen zevenentwintig biljard zevenhonderdvijftig biljoen zeshonderdtwintig miljard vijfhonderddrieënzestig miljoen zeshonderdtweeënzestigduizendzesennegentig")
  , (26925748508234281076009, "zesentwintig triljard negenhonderdvijfentwintig triljoen zevenhonderdachtenveertig biljard vijfhonderdacht biljoen tweehonderdvierendertig miljard tweehonderdeenentachtig miljoen zesenzeventigduizendnegen")
  , (43566776258854844738105, "drieënveertig triljard vijfhonderdzesenzestig triljoen zevenhonderdzesenzeventig biljard tweehonderdachtenvijftig biljoen achthonderdvierenvijftig miljard achthonderdvierenveertig miljoen zevenhonderdachtendertigduizendhonderdvijf")
  , (70492524767089125814114, "zeventig triljard vierhonderdtweeënnegentig triljoen vijfhonderdvierentwintig biljard zevenhonderdzevenenzestig biljoen negenentachtig miljard honderdvijfentwintig miljoen achthonderdveertienduizendhonderdveertien")
  , (114059301025943970552219, "honderdveertien triljard negenenvijftig triljoen driehonderdéén biljard vijfentwintig biljoen negenhonderddrieënveertig miljard negenhonderdzeventig miljoen vijfhonderdtweeënvijftigduizendtweehonderdnegentien")
  , (1000, "duizend")
  , (10000, "tienduizend")
  , (100000, "honderdduizend")
  , (1000000, "een miljoen")
  , (10000000, "tien miljoen")
  , (100000000, "honderd miljoen")
  , (1000000000, "een miljard")
  , (10000000000, "tien miljard")
  , (100000000000, "honderd miljard")
  , (1000000000000, "een biljoen")
  , (10000000000000, "tien biljoen")
  , (100000000000000, "honderd biljoen")
  , (1000000000000000, "een biljard")
  , (10000000000000000, "tien biljard")
  , (100000000000000000, "honderd biljard")
  , (1000000000000000000, "een triljoen")
  , (10000000000000000000, "tien triljoen")
  , (100000000000000000000, "honderd triljoen")
  , (1000000000000000000000, "een triljard")
  , (10000000000000000000000, "tien triljard")
  , (100000000000000000000000, "honderd triljard")
  , (1000000000000000000000000, "een quadriljoen")
  ]

ordinals :: [(Integer, Text)]
ordinals = [
    (0, "nulde")
  , (1, "eerste")
  , (2, "tweede")
  , (3, "derde")
  , (4, "vierde")
  , (5, "vijfde")
  , (6, "zesde")
  , (7, "zevende")
  , (8, "achtste")
  , (9, "negende")
  , (10, "tiende")
  , (11, "elfde")
  , (12, "twaalfde")
  , (13, "dertiende")
  , (14, "veertiende")
  , (15, "vijftiende")
  , (16, "zestiende")
  , (17, "zeventiende")
  , (18, "achttiende")
  , (19, "negentiende")
  , (20, "twintigste")
  , (21, "eenentwintigste")
  , (22, "tweeëntwintigste")
  , (23, "drieëntwintigste")
  , (24, "vierentwintigste")
  , (25, "vijfentwintigste")
  , (26, "zesentwintigste")
  , (27, "zevenentwintigste")
  , (28, "achtentwintigste")
  , (29, "negenentwintigste")
  , (30, "dertigste")
  , (31, "eenendertigste")
  , (32, "tweeëndertigste")
  , (33, "drieëndertigste")
  , (34, "vierendertigste")
  , (35, "vijfendertigste")
  , (36, "zesendertigste")
  , (37, "zevenendertigste")
  , (38, "achtendertigste")
  , (39, "negenendertigste")
  , (40, "veertigste")
  , (41, "eenenveertigste")
  , (42, "tweeënveertigste")
  , (43, "drieënveertigste")
  , (44, "vierenveertigste")
  , (45, "vijfenveertigste")
  , (46, "zesenveertigste")
  , (47, "zevenenveertigste")
  , (48, "achtenveertigste")
  , (49, "negenenveertigste")
  , (50, "vijftigste")
  , (51, "eenenvijftigste")
  , (52, "tweeënvijftigste")
  , (53, "drieënvijftigste")
  , (54, "vierenvijftigste")
  , (55, "vijfenvijftigste")
  , (56, "zesenvijftigste")
  , (57, "zevenenvijftigste")
  , (58, "achtenvijftigste")
  , (59, "negenenvijftigste")
  , (60, "zestigste")
  , (61, "eenenzestigste")
  , (62, "tweeënzestigste")
  , (63, "drieënzestigste")
  , (64, "vierenzestigste")
  , (65, "vijfenzestigste")
  , (66, "zesenzestigste")
  , (67, "zevenenzestigste")
  , (68, "achtenzestigste")
  , (69, "negenenzestigste")
  , (70, "zeventigste")
  , (71, "eenenzeventigste")
  , (72, "tweeënzeventigste")
  , (73, "drieënzeventigste")
  , (74, "vierenzeventigste")
  , (75, "vijfenzeventigste")
  , (76, "zesenzeventigste")
  , (77, "zevenenzeventigste")
  , (78, "achtenzeventigste")
  , (79, "negenenzeventigste")
  , (80, "tachtigste")
  , (81, "eenentachtigste")
  , (82, "tweeëntachtigste")
  , (83, "drieëntachtigste")
  , (84, "vierentachtigste")
  , (85, "vijfentachtigste")
  , (86, "zesentachtigste")
  , (87, "zevenentachtigste")
  , (88, "achtentachtigste")
  , (89, "negenentachtigste")
  , (90, "negentigste")
  , (91, "eenennegentigste")
  , (92, "tweeënnegentigste")
  , (93, "drieënnegentigste")
  , (94, "vierennegentigste")
  , (95, "vijfennegentigste")
  , (96, "zesennegentigste")
  , (97, "zevenennegentigste")
  , (98, "achtennegentigste")
  , (99, "negenennegentigste")
  , (100, "honderdste")
  , (101, "honderdeerste")
  , (102, "honderdtweede")
  , (103, "honderdderde")
  , (104, "honderdvierde")
  , (105, "honderdvijfde")
  , (106, "honderdzesde")
  , (107, "honderdzevende")
  , (108, "honderdachtste")
  , (109, "honderdnegende")
  , (110, "honderdtiende")
  , (111, "honderdelfde")
  , (112, "honderdtwaalfde")
  , (113, "honderddertiende")
  , (114, "honderdveertiende")
  , (115, "honderdvijftiende")
  , (116, "honderdzestiende")
  , (117, "honderdzeventiende")
  , (118, "honderdachttiende")
  , (119, "honderdnegentiende")
  , (120, "honderdtwintigste")
  , (121, "honderdeenentwintigste")
  , (122, "honderdtweeëntwintigste")
  , (123, "honderddrieëntwintigste")
  , (124, "honderdvierentwintigste")
  , (125, "honderdvijfentwintigste")
  , (126, "honderdzesentwintigste")
  , (127, "honderdzevenentwintigste")
  , (128, "honderdachtentwintigste")
  , (129, "honderdnegenentwintigste")
  , (130, "honderddertigste")
  , (131, "honderdeenendertigste")
  , (132, "honderdtweeëndertigste")
  , (133, "honderddrieëndertigste")
  , (134, "honderdvierendertigste")
  , (135, "honderdvijfendertigste")
  , (136, "honderdzesendertigste")
  , (137, "honderdzevenendertigste")
  , (138, "honderdachtendertigste")
  , (139, "honderdnegenendertigste")
  , (140, "honderdveertigste")
  , (141, "honderdeenenveertigste")
  , (142, "honderdtweeënveertigste")
  , (143, "honderddrieënveertigste")
  , (144, "honderdvierenveertigste")
  , (145, "honderdvijfenveertigste")
  , (146, "honderdzesenveertigste")
  , (147, "honderdzevenenveertigste")
  , (148, "honderdachtenveertigste")
  , (149, "honderdnegenenveertigste")
  , (150, "honderdvijftigste")
  , (151, "honderdeenenvijftigste")
  , (152, "honderdtweeënvijftigste")
  , (153, "honderddrieënvijftigste")
  , (154, "honderdvierenvijftigste")
  , (155, "honderdvijfenvijftigste")
  , (156, "honderdzesenvijftigste")
  , (157, "honderdzevenenvijftigste")
  , (158, "honderdachtenvijftigste")
  , (159, "honderdnegenenvijftigste")
  , (160, "honderdzestigste")
  , (161, "honderdeenenzestigste")
  , (162, "honderdtweeënzestigste")
  , (163, "honderddrieënzestigste")
  , (164, "honderdvierenzestigste")
  , (165, "honderdvijfenzestigste")
  , (166, "honderdzesenzestigste")
  , (167, "honderdzevenenzestigste")
  , (168, "honderdachtenzestigste")
  , (169, "honderdnegenenzestigste")
  , (170, "honderdzeventigste")
  , (171, "honderdeenenzeventigste")
  , (172, "honderdtweeënzeventigste")
  , (173, "honderddrieënzeventigste")
  , (174, "honderdvierenzeventigste")
  , (175, "honderdvijfenzeventigste")
  , (176, "honderdzesenzeventigste")
  , (177, "honderdzevenenzeventigste")
  , (178, "honderdachtenzeventigste")
  , (179, "honderdnegenenzeventigste")
  , (180, "honderdtachtigste")
  , (181, "honderdeenentachtigste")
  , (182, "honderdtweeëntachtigste")
  , (183, "honderddrieëntachtigste")
  , (184, "honderdvierentachtigste")
  , (185, "honderdvijfentachtigste")
  , (186, "honderdzesentachtigste")
  , (187, "honderdzevenentachtigste")
  , (188, "honderdachtentachtigste")
  , (189, "honderdnegenentachtigste")
  , (190, "honderdnegentigste")
  , (191, "honderdeenennegentigste")
  , (192, "honderdtweeënnegentigste")
  , (193, "honderddrieënnegentigste")
  , (194, "honderdvierennegentigste")
  , (195, "honderdvijfennegentigste")
  , (196, "honderdzesennegentigste")
  , (197, "honderdzevenennegentigste")
  , (198, "honderdachtennegentigste")
  , (199, "honderdnegenennegentigste")
  , (200, "tweehonderdste")
  , (233, "tweehonderddrieëndertigste")
  , (377, "driehonderdzevenenzeventigste")
  , (610, "zeshonderdtiende")
  , (987, "negenhonderdzevenentachtigste")
  , (1597, "duizendvijfhonderdzevenennegentigste")
  , (2584, "tweeduizendvijfhonderdvierentachtigste")
  , (4181, "vierduizendhonderdeenentachtigste")
  , (6765, "zesduizendzevenhonderdvijfenzestigste")
  , (10946, "tienduizendnegenhonderdzesenveertigste")
  , (17711, "zeventienduizendzevenhonderdelfde")
  , (28657, "achtentwintigduizendzeshonderdzevenenvijftigste")
  , (46368, "zesenveertigduizenddriehonderdachtenzestigste")
  , (75025, "vijfenzeventigduizendvijfentwintigste")
  , (121393, "honderdeenentwintigduizenddriehonderddrieënnegentigste")
  , (196418, "honderdzesennegentigduizendvierhonderdachttiende")
  , (317811, "driehonderdzeventienduizendachthonderdelfde")
  , (514229, "vijfhonderdveertienduizendtweehonderdnegenentwintigste")
  , (832040, "achthonderdtweeëndertigduizendveertigste")
  , (1346269, "een miljoen driehonderdzesenveertigduizendtweehonderdnegenenzestigste")
  , (2178309, "twee miljoen honderdachtenzeventigduizenddriehonderdnegende")
  , (3524578, "drie miljoen vijfhonderdvierentwintigduizendvijfhonderdachtenzeventigste")
  , (5702887, "vijf miljoen zevenhonderdtweeduizendachthonderdzevenentachtigste")
  , (9227465, "negen miljoen tweehonderdzevenentwintigduizendvierhonderdvijfenzestigste")
  , (14930352, "veertien miljoen negenhonderddertigduizenddriehonderdtweeënvijftigste")
  , (24157817, "vierentwintig miljoen honderdzevenenvijftigduizendachthonderdzeventiende")
  , (39088169, "negenendertig miljoen achtentachtigduizendhonderdnegenenzestigste")
  , (63245986, "drieënzestig miljoen tweehonderdvijfenveertigduizendnegenhonderdzesentachtigste")
  , (102334155, "honderdtwee miljoen driehonderdvierendertigduizendhonderdvijfenvijftigste")
  , (165580141, "honderdvijfenzestig miljoen vijfhonderdtachtigduizendhonderdeenenveertigste")
  , (267914296, "tweehonderdzevenenzestig miljoen negenhonderdveertienduizendtweehonderdzesennegentigste")
  , (433494437, "vierhonderddrieëndertig miljoen vierhonderdvierennegentigduizendvierhonderdzevenendertigste")
  , (701408733, "zevenhonderdéén miljoen vierhonderdachtduizendzevenhonderddrieëndertigste")
  , (1134903170, "een miljard honderdvierendertig miljoen negenhonderddrieduizendhonderdzeventigste")
  , (1836311903, "een miljard achthonderdzesendertig miljoen driehonderdelfduizendnegenhonderdderde")
  , (2971215073, "twee miljard negenhonderdeenenzeventig miljoen tweehonderdvijftienduizenddrieënzeventigste")
  , (4807526976, "vier miljard achthonderdzeven miljoen vijfhonderdzesentwintigduizendnegenhonderdzesenzeventigste")
  , (7778742049, "zeven miljard zevenhonderdachtenzeventig miljoen zevenhonderdtweeënveertigduizendnegenenveertigste")
  , (12586269025, "twaalf miljard vijfhonderdzesentachtig miljoen tweehonderdnegenenzestigduizendvijfentwintigste")
  , (20365011074, "twintig miljard driehonderdvijfenzestig miljoen elfduizendvierenzeventigste")
  , (32951280099, "tweeëndertig miljard negenhonderdeenenvijftig miljoen tweehonderdtachtigduizendnegenennegentigste")
  , (53316291173, "drieënvijftig miljard driehonderdzestien miljoen tweehonderdeenennegentigduizendhonderddrieënzeventigste")
  , (86267571272, "zesentachtig miljard tweehonderdzevenenzestig miljoen vijfhonderdeenenzeventigduizendtweehonderdtweeënzeventigste")
  , (139583862445, "honderdnegenendertig miljard vijfhonderddrieëntachtig miljoen achthonderdtweeënzestigduizendvierhonderdvijfenveertigste")
  , (225851433717, "tweehonderdvijfentwintig miljard achthonderdeenenvijftig miljoen vierhonderddrieëndertigduizendzevenhonderdzeventiende")
  , (365435296162, "driehonderdvijfenzestig miljard vierhonderdvijfendertig miljoen tweehonderdzesennegentigduizendhonderdtweeënzestigste")
  , (591286729879, "vijfhonderdeenennegentig miljard tweehonderdzesentachtig miljoen zevenhonderdnegenentwintigduizendachthonderdnegenenzeventigste")
  , (956722026041, "negenhonderdzesenvijftig miljard zevenhonderdtweeëntwintig miljoen zesentwintigduizendeenenveertigste")
  , (1548008755920, "een biljoen vijfhonderdachtenveertig miljard acht miljoen zevenhonderdvijfenvijftigduizendnegenhonderdtwintigste")
  , (2504730781961, "twee biljoen vijfhonderdvier miljard zevenhonderddertig miljoen zevenhonderdeenentachtigduizendnegenhonderdeenenzestigste")
  , (4052739537881, "vier biljoen tweeënvijftig miljard zevenhonderdnegenendertig miljoen vijfhonderdzevenendertigduizendachthonderdeenentachtigste")
  , (6557470319842, "zes biljoen vijfhonderdzevenenvijftig miljard vierhonderdzeventig miljoen driehonderdnegentienduizendachthonderdtweeënveertigste")
  , (10610209857723, "tien biljoen zeshonderdtien miljard tweehonderdnegen miljoen achthonderdzevenenvijftigduizendzevenhonderddrieëntwintigste")
  , (17167680177565, "zeventien biljoen honderdzevenenzestig miljard zeshonderdtachtig miljoen honderdzevenenzeventigduizendvijfhonderdvijfenzestigste")
  , (27777890035288, "zevenentwintig biljoen zevenhonderdzevenenzeventig miljard achthonderdnegentig miljoen vijfendertigduizendtweehonderdachtentachtigste")
  , (44945570212853, "vierenveertig biljoen negenhonderdvijfenveertig miljard vijfhonderdzeventig miljoen tweehonderdtwaalfduizendachthonderddrieënvijftigste")
  , (72723460248141, "tweeënzeventig biljoen zevenhonderddrieëntwintig miljard vierhonderdzestig miljoen tweehonderdachtenveertigduizendhonderdeenenveertigste")
  , (117669030460994, "honderdzeventien biljoen zeshonderdnegenenzestig miljard dertig miljoen vierhonderdzestigduizendnegenhonderdvierennegentigste")
  , (190392490709135, "honderdnegentig biljoen driehonderdtweeënnegentig miljard vierhonderdnegentig miljoen zevenhonderdnegenduizendhonderdvijfendertigste")
  , (308061521170129, "driehonderdacht biljoen eenenzestig miljard vijfhonderdeenentwintig miljoen honderdzeventigduizendhonderdnegenentwintigste")
  , (498454011879264, "vierhonderdachtennegentig biljoen vierhonderdvierenvijftig miljard elf miljoen achthonderdnegenenzeventigduizendtweehonderdvierenzestigste")
  , (806515533049393, "achthonderdzes biljoen vijfhonderdvijftien miljard vijfhonderddrieëndertig miljoen negenenveertigduizenddriehonderddrieënnegentigste")
  , (1304969544928657, "een biljard driehonderdvier biljoen negenhonderdnegenenzestig miljard vijfhonderdvierenveertig miljoen negenhonderdachtentwintigduizendzeshonderdzevenenvijftigste")
  , (2111485077978050, "twee biljard honderdelf biljoen vierhonderdvijfentachtig miljard zevenenzeventig miljoen negenhonderdachtenzeventigduizendvijftigste")
  , (3416454622906707, "drie biljard vierhonderdzestien biljoen vierhonderdvierenvijftig miljard zeshonderdtweeëntwintig miljoen negenhonderdzesduizendzevenhonderdzevende")
  , (5527939700884757, "vijf biljard vijfhonderdzevenentwintig biljoen negenhonderdnegenendertig miljard zevenhonderd miljoen achthonderdvierentachtigduizendzevenhonderdzevenenvijftigste")
  , (8944394323791464, "acht biljard negenhonderdvierenveertig biljoen driehonderdvierennegentig miljard driehonderddrieëntwintig miljoen zevenhonderdeenennegentigduizendvierhonderdvierenzestigste")
  , (14472334024676221, "veertien biljard vierhonderdtweeënzeventig biljoen driehonderdvierendertig miljard vierentwintig miljoen zeshonderdzesenzeventigduizendtweehonderdeenentwintigste")
  , (23416728348467685, "drieëntwintig biljard vierhonderdzestien biljoen zevenhonderdachtentwintig miljard driehonderdachtenveertig miljoen vierhonderdzevenenzestigduizendzeshonderdvijfentachtigste")
  , (37889062373143906, "zevenendertig biljard achthonderdnegenentachtig biljoen tweeënzestig miljard driehonderddrieënzeventig miljoen honderddrieënveertigduizendnegenhonderdzesde")
  , (61305790721611591, "eenenzestig biljard driehonderdvijf biljoen zevenhonderdnegentig miljard zevenhonderdeenentwintig miljoen zeshonderdelfduizendvijfhonderdeenennegentigste")
  , (99194853094755497, "negenennegentig biljard honderdvierennegentig biljoen achthonderddrieënvijftig miljard vierennegentig miljoen zevenhonderdvijfenvijftigduizendvierhonderdzevenennegentigste")
  , (160500643816367088, "honderdzestig biljard vijfhonderd biljoen zeshonderddrieënveertig miljard achthonderdzestien miljoen driehonderdzevenenzestigduizendachtentachtigste")
  , (259695496911122585, "tweehonderdnegenenvijftig biljard zeshonderdvijfennegentig biljoen vierhonderdzesennegentig miljard negenhonderdelf miljoen honderdtweeëntwintigduizendvijfhonderdvijfentachtigste")
  , (420196140727489673, "vierhonderdtwintig biljard honderdzesennegentig biljoen honderdveertig miljard zevenhonderdzevenentwintig miljoen vierhonderdnegenentachtigduizendzeshonderddrieënzeventigste")
  , (679891637638612258, "zeshonderdnegenenzeventig biljard achthonderdeenennegentig biljoen zeshonderdzevenendertig miljard zeshonderdachtendertig miljoen zeshonderdtwaalfduizendtweehonderdachtenvijftigste")
  , (1100087778366101931, "een triljoen honderd biljard zevenentachtig biljoen zevenhonderdachtenzeventig miljard driehonderdzesenzestig miljoen honderdéénduizendnegenhonderdeenendertigste")
  , (1779979416004714189, "een triljoen zevenhonderdnegenenzeventig biljard negenhonderdnegenenzeventig biljoen vierhonderdzestien miljard vier miljoen zevenhonderdveertienduizendhonderdnegenentachtigste")
  , (2880067194370816120, "twee triljoen achthonderdtachtig biljard zevenenzestig biljoen honderdvierennegentig miljard driehonderdzeventig miljoen achthonderdzestienduizendhonderdtwintigste")
  , (4660046610375530309, "vier triljoen zeshonderdzestig biljard zesenveertig biljoen zeshonderdtien miljard driehonderdvijfenzeventig miljoen vijfhonderddertigduizenddriehonderdnegende")
  , (7540113804746346429, "zeven triljoen vijfhonderdveertig biljard honderddertien biljoen achthonderdvier miljard zevenhonderdzesenveertig miljoen driehonderdzesenveertigduizendvierhonderdnegenentwintigste")
  , (12200160415121876738, "twaalf triljoen tweehonderd biljard honderdzestig biljoen vierhonderdvijftien miljard honderdeenentwintig miljoen achthonderdzesenzeventigduizendzevenhonderdachtendertigste")
  , (19740274219868223167, "negentien triljoen zevenhonderdveertig biljard tweehonderdvierenzeventig biljoen tweehonderdnegentien miljard achthonderdachtenzestig miljoen tweehonderddrieëntwintigduizendhonderdzevenenzestigste")
  , (31940434634990099905, "eenendertig triljoen negenhonderdveertig biljard vierhonderdvierendertig biljoen zeshonderdvierendertig miljard negenhonderdnegentig miljoen negenennegentigduizendnegenhonderdvijfde")
  , (51680708854858323072, "eenenvijftig triljoen zeshonderdtachtig biljard zevenhonderdacht biljoen achthonderdvierenvijftig miljard achthonderdachtenvijftig miljoen driehonderddrieëntwintigduizendtweeënzeventigste")
  , (83621143489848422977, "drieëntachtig triljoen zeshonderdeenentwintig biljard honderddrieënveertig biljoen vierhonderdnegenentachtig miljard achthonderdachtenveertig miljoen vierhonderdtweeëntwintigduizendnegenhonderdzevenenzeventigste")
  , (135301852344706746049, "honderdvijfendertig triljoen driehonderdéén biljard achthonderdtweeënvijftig biljoen driehonderdvierenveertig miljard zevenhonderdzes miljoen zevenhonderdzesenveertigduizendnegenenveertigste")
  , (218922995834555169026, "tweehonderdachttien triljoen negenhonderdtweeëntwintig biljard negenhonderdvijfennegentig biljoen achthonderdvierendertig miljard vijfhonderdvijfenvijftig miljoen honderdnegenenzestigduizendzesentwintigste")
  , (354224848179261915075, "driehonderdvierenvijftig triljoen tweehonderdvierentwintig biljard achthonderdachtenveertig biljoen honderdnegenenzeventig miljard tweehonderdeenenzestig miljoen negenhonderdvijftienduizendvijfenzeventigste")
  , (573147844013817084101, "vijfhonderddrieënzeventig triljoen honderdzevenenveertig biljard achthonderdvierenveertig biljoen dertien miljard achthonderdzeventien miljoen vierentachtigduizendhonderdeerste")
  , (927372692193078999176, "negenhonderdzevenentwintig triljoen driehonderdtweeënzeventig biljard zeshonderdtweeënnegentig biljoen honderddrieënnegentig miljard achtenzeventig miljoen negenhonderdnegenennegentigduizendhonderdzesenzeventigste")
  , (1500520536206896083277, "een triljard vijfhonderd triljoen vijfhonderdtwintig biljard vijfhonderdzesendertig biljoen tweehonderdzes miljard achthonderdzesennegentig miljoen drieëntachtigduizendtweehonderdzevenenzeventigste")
  , (2427893228399975082453, "twee triljard vierhonderdzevenentwintig triljoen achthonderddrieënnegentig biljard tweehonderdachtentwintig biljoen driehonderdnegenennegentig miljard negenhonderdvijfenzeventig miljoen tweeëntachtigduizendvierhonderddrieënvijftigste")
  , (3928413764606871165730, "drie triljard negenhonderdachtentwintig triljoen vierhonderddertien biljard zevenhonderdvierenzestig biljoen zeshonderdzes miljard achthonderdeenenzeventig miljoen honderdvijfenzestigduizendzevenhonderddertigste")
  , (6356306993006846248183, "zes triljard driehonderdzesenvijftig triljoen driehonderdzes biljard negenhonderddrieënnegentig biljoen zes miljard achthonderdzesenveertig miljoen tweehonderdachtenveertigduizendhonderddrieëntachtigste")
  , (10284720757613717413913, "tien triljard tweehonderdvierentachtig triljoen zevenhonderdtwintig biljard zevenhonderdzevenenvijftig biljoen zeshonderddertien miljard zevenhonderdzeventien miljoen vierhonderddertienduizendnegenhonderddertiende")
  , (16641027750620563662096, "zestien triljard zeshonderdeenenveertig triljoen zevenentwintig biljard zevenhonderdvijftig biljoen zeshonderdtwintig miljard vijfhonderddrieënzestig miljoen zeshonderdtweeënzestigduizendzesennegentigste")
  , (26925748508234281076009, "zesentwintig triljard negenhonderdvijfentwintig triljoen zevenhonderdachtenveertig biljard vijfhonderdacht biljoen tweehonderdvierendertig miljard tweehonderdeenentachtig miljoen zesenzeventigduizendnegende")
  , (43566776258854844738105, "drieënveertig triljard vijfhonderdzesenzestig triljoen zevenhonderdzesenzeventig biljard tweehonderdachtenvijftig biljoen achthonderdvierenvijftig miljard achthonderdvierenveertig miljoen zevenhonderdachtendertigduizendhonderdvijfde")
  , (70492524767089125814114, "zeventig triljard vierhonderdtweeënnegentig triljoen vijfhonderdvierentwintig biljard zevenhonderdzevenenzestig biljoen negenentachtig miljard honderdvijfentwintig miljoen achthonderdveertienduizendhonderdveertiende")
  , (114059301025943970552219, "honderdveertien triljard negenenvijftig triljoen driehonderdéén biljard vijfentwintig biljoen negenhonderddrieënveertig miljard negenhonderdzeventig miljoen vijfhonderdtweeënvijftigduizendtweehonderdnegentiende")
  , (1000, "duizendste")
  , (10000, "tienduizendste")
  , (100000, "honderdduizendste")
  , (1000000, "een miljoenste")
  , (10000000, "tien miljoenste")
  , (100000000, "honderd miljoenste")
  , (1000000000, "een miljardste")
  , (10000000000, "tien miljardste")
  , (100000000000, "honderd miljardste")
  , (1000000000000, "een biljoenste")
  , (10000000000000, "tien biljoenste")
  , (100000000000000, "honderd biljoenste")
  , (1000000000000000, "een biljardste")
  , (10000000000000000, "tien biljardste")
  , (100000000000000000, "honderd biljardste")
  , (1000000000000000000, "een triljoenste")
  , (10000000000000000000, "tien triljoenste")
  , (100000000000000000000, "honderd triljoenste")
  , (1000000000000000000000, "een triljardste")
  , (10000000000000000000000, "tien triljardste")
  , (100000000000000000000000, "honderd triljardste")
  , (1000000000000000000000000, "een quadriljoenste")
  ]
