module Text.Numerals.Languages.FrenchSpec (
    spec
  ) where

import Data.Text(Text)

import Test.Hspec(Spec)
import Text.Numerals.Languages.French(french)
import Text.Numerals.LanguageTest(testLanguage)

spec :: Spec
spec = testLanguage "French" french cardinals ordinals

cardinals :: [(Integer, Text)]
cardinals = [
    (0, "zéro")
  , (1, "un")
  , (2, "deux")
  , (3, "trois")
  , (4, "quatre")
  , (5, "cinq")
  , (6, "six")
  , (7, "sept")
  , (8, "huit")
  , (9, "neuf")
  , (10, "dix")
  , (11, "onze")
  , (12, "douze")
  , (13, "treize")
  , (14, "quatorze")
  , (15, "quinze")
  , (16, "seize")
  , (17, "dix-sept")
  , (18, "dix-huit")
  , (19, "dix-neuf")
  , (20, "vingt")
  , (21, "vingt et un")
  , (22, "vingt-deux")
  , (23, "vingt-trois")
  , (24, "vingt-quatre")
  , (25, "vingt-cinq")
  , (26, "vingt-six")
  , (27, "vingt-sept")
  , (28, "vingt-huit")
  , (29, "vingt-neuf")
  , (30, "trente")
  , (31, "trente et un")
  , (32, "trente-deux")
  , (33, "trente-trois")
  , (34, "trente-quatre")
  , (35, "trente-cinq")
  , (36, "trente-six")
  , (37, "trente-sept")
  , (38, "trente-huit")
  , (39, "trente-neuf")
  , (40, "quarante")
  , (41, "quarante et un")
  , (42, "quarante-deux")
  , (43, "quarante-trois")
  , (44, "quarante-quatre")
  , (45, "quarante-cinq")
  , (46, "quarante-six")
  , (47, "quarante-sept")
  , (48, "quarante-huit")
  , (49, "quarante-neuf")
  , (50, "cinquante")
  , (51, "cinquante et un")
  , (52, "cinquante-deux")
  , (53, "cinquante-trois")
  , (54, "cinquante-quatre")
  , (55, "cinquante-cinq")
  , (56, "cinquante-six")
  , (57, "cinquante-sept")
  , (58, "cinquante-huit")
  , (59, "cinquante-neuf")
  , (60, "soixante")
  , (61, "soixante et un")
  , (62, "soixante-deux")
  , (63, "soixante-trois")
  , (64, "soixante-quatre")
  , (65, "soixante-cinq")
  , (66, "soixante-six")
  , (67, "soixante-sept")
  , (68, "soixante-huit")
  , (69, "soixante-neuf")
  , (70, "soixante-dix")
  , (71, "soixante et onze")
  , (72, "soixante-douze")
  , (73, "soixante-treize")
  , (74, "soixante-quatorze")
  , (75, "soixante-quinze")
  , (76, "soixante-seize")
  , (77, "soixante-dix-sept")
  , (78, "soixante-dix-huit")
  , (79, "soixante-dix-neuf")
  , (80, "quatre-vingts")
  , (81, "quatre-vingt-un")
  , (82, "quatre-vingt-deux")
  , (83, "quatre-vingt-trois")
  , (84, "quatre-vingt-quatre")
  , (85, "quatre-vingt-cinq")
  , (86, "quatre-vingt-six")
  , (87, "quatre-vingt-sept")
  , (88, "quatre-vingt-huit")
  , (89, "quatre-vingt-neuf")
  , (90, "quatre-vingt-dix")
  , (91, "quatre-vingt-onze")
  , (92, "quatre-vingt-douze")
  , (93, "quatre-vingt-treize")
  , (94, "quatre-vingt-quatorze")
  , (95, "quatre-vingt-quinze")
  , (96, "quatre-vingt-seize")
  , (97, "quatre-vingt-dix-sept")
  , (98, "quatre-vingt-dix-huit")
  , (99, "quatre-vingt-dix-neuf")
  , (100, "cent")
  , (101, "cent un")
  , (102, "cent deux")
  , (103, "cent trois")
  , (104, "cent quatre")
  , (105, "cent cinq")
  , (106, "cent six")
  , (107, "cent sept")
  , (108, "cent huit")
  , (109, "cent neuf")
  , (110, "cent dix")
  , (111, "cent onze")
  , (112, "cent douze")
  , (113, "cent treize")
  , (114, "cent quatorze")
  , (115, "cent quinze")
  , (116, "cent seize")
  , (117, "cent dix-sept")
  , (118, "cent dix-huit")
  , (119, "cent dix-neuf")
  , (120, "cent vingt")
  , (121, "cent vingt et un")
  , (122, "cent vingt-deux")
  , (123, "cent vingt-trois")
  , (124, "cent vingt-quatre")
  , (125, "cent vingt-cinq")
  , (126, "cent vingt-six")
  , (127, "cent vingt-sept")
  , (128, "cent vingt-huit")
  , (129, "cent vingt-neuf")
  , (130, "cent trente")
  , (131, "cent trente et un")
  , (132, "cent trente-deux")
  , (133, "cent trente-trois")
  , (134, "cent trente-quatre")
  , (135, "cent trente-cinq")
  , (136, "cent trente-six")
  , (137, "cent trente-sept")
  , (138, "cent trente-huit")
  , (139, "cent trente-neuf")
  , (140, "cent quarante")
  , (141, "cent quarante et un")
  , (142, "cent quarante-deux")
  , (143, "cent quarante-trois")
  , (144, "cent quarante-quatre")
  , (145, "cent quarante-cinq")
  , (146, "cent quarante-six")
  , (147, "cent quarante-sept")
  , (148, "cent quarante-huit")
  , (149, "cent quarante-neuf")
  , (150, "cent cinquante")
  , (151, "cent cinquante et un")
  , (152, "cent cinquante-deux")
  , (153, "cent cinquante-trois")
  , (154, "cent cinquante-quatre")
  , (155, "cent cinquante-cinq")
  , (156, "cent cinquante-six")
  , (157, "cent cinquante-sept")
  , (158, "cent cinquante-huit")
  , (159, "cent cinquante-neuf")
  , (160, "cent soixante")
  , (161, "cent soixante et un")
  , (162, "cent soixante-deux")
  , (163, "cent soixante-trois")
  , (164, "cent soixante-quatre")
  , (165, "cent soixante-cinq")
  , (166, "cent soixante-six")
  , (167, "cent soixante-sept")
  , (168, "cent soixante-huit")
  , (169, "cent soixante-neuf")
  , (170, "cent soixante-dix")
  , (171, "cent soixante et onze")
  , (172, "cent soixante-douze")
  , (173, "cent soixante-treize")
  , (174, "cent soixante-quatorze")
  , (175, "cent soixante-quinze")
  , (176, "cent soixante-seize")
  , (177, "cent soixante-dix-sept")
  , (178, "cent soixante-dix-huit")
  , (179, "cent soixante-dix-neuf")
  , (180, "cent quatre-vingts")
  , (181, "cent quatre-vingt-un")
  , (182, "cent quatre-vingt-deux")
  , (183, "cent quatre-vingt-trois")
  , (184, "cent quatre-vingt-quatre")
  , (185, "cent quatre-vingt-cinq")
  , (186, "cent quatre-vingt-six")
  , (187, "cent quatre-vingt-sept")
  , (188, "cent quatre-vingt-huit")
  , (189, "cent quatre-vingt-neuf")
  , (190, "cent quatre-vingt-dix")
  , (191, "cent quatre-vingt-onze")
  , (192, "cent quatre-vingt-douze")
  , (193, "cent quatre-vingt-treize")
  , (194, "cent quatre-vingt-quatorze")
  , (195, "cent quatre-vingt-quinze")
  , (196, "cent quatre-vingt-seize")
  , (197, "cent quatre-vingt-dix-sept")
  , (198, "cent quatre-vingt-dix-huit")
  , (199, "cent quatre-vingt-dix-neuf")
  , (200, "deux cents")
  , (233, "deux cent trente-trois")
  , (377, "trois cent soixante-dix-sept")
  , (610, "six cent dix")
  , (987, "neuf cent quatre-vingt-sept")
  , (1597, "mille cinq cent quatre-vingt-dix-sept")
  , (2584, "deux mille cinq cent quatre-vingt-quatre")
  , (4181, "quatre mille cent quatre-vingt-un")
  , (6765, "six mille sept cent soixante-cinq")
  , (10946, "dix mille neuf cent quarante-six")
  , (17711, "dix-sept mille sept cent onze")
  , (28657, "vingt-huit mille six cent cinquante-sept")
  , (46368, "quarante-six mille trois cent soixante-huit")
  , (75025, "soixante-quinze mille vingt-cinq")
  , (121393, "cent vingt et un mille trois cent quatre-vingt-treize")
  , (196418, "cent quatre-vingt-seize mille quatre cent dix-huit")
  , (317811, "trois cent dix-sept mille huit cent onze")
  , (514229, "cinq cent quatorze mille deux cent vingt-neuf")
  , (832040, "huit cent trente-deux mille quarante")
  , (1346269, "un million trois cent quarante-six mille deux cent soixante-neuf")
  , (2178309, "deux millions cent soixante-dix-huit mille trois cent neuf")
  , (3524578, "trois millions cinq cent vingt-quatre mille cinq cent soixante-dix-huit")
  , (5702887, "cinq millions sept cent deux mille huit cent quatre-vingt-sept")
  , (9227465, "neuf millions deux cent vingt-sept mille quatre cent soixante-cinq")
  , (14930352, "quatorze millions neuf cent trente mille trois cent cinquante-deux")
  , (24157817, "vingt-quatre millions cent cinquante-sept mille huit cent dix-sept")
  , (39088169, "trente-neuf millions quatre-vingt-huit mille cent soixante-neuf")
  , (63245986, "soixante-trois millions deux cent quarante-cinq mille neuf cent quatre-vingt-six")
  , (102334155, "cent deux millions trois cent trente-quatre mille cent cinquante-cinq")
  , (165580141, "cent soixante-cinq millions cinq cent quatre-vingt mille cent quarante et un")
  , (267914296, "deux cent soixante-sept millions neuf cent quatorze mille deux cent quatre-vingt-seize")
  , (433494437, "quatre cent trente-trois millions quatre cent quatre-vingt-quatorze mille quatre cent trente-sept")
  , (701408733, "sept cent un millions quatre cent huit mille sept cent trente-trois")
  , (1134903170, "un milliard cent trente-quatre millions neuf cent trois mille cent soixante-dix")
  , (1836311903, "un milliard huit cent trente-six millions trois cent onze mille neuf cent trois")
  , (2971215073, "deux milliards neuf cent soixante et onze millions deux cent quinze mille soixante-treize")
  , (4807526976, "quatre milliards huit cent sept millions cinq cent vingt-six mille neuf cent soixante-seize")
  , (7778742049, "sept milliards sept cent soixante-dix-huit millions sept cent quarante-deux mille quarante-neuf")
  , (12586269025, "douze milliards cinq cent quatre-vingt-six millions deux cent soixante-neuf mille vingt-cinq")
  , (20365011074, "vingt milliards trois cent soixante-cinq millions onze mille soixante-quatorze")
  , (32951280099, "trente-deux milliards neuf cent cinquante et un millions deux cent quatre-vingt mille quatre-vingt-dix-neuf")
  , (53316291173, "cinquante-trois milliards trois cent seize millions deux cent quatre-vingt-onze mille cent soixante-treize")
  , (86267571272, "quatre-vingt-six milliards deux cent soixante-sept millions cinq cent soixante et onze mille deux cent soixante-douze")
  , (139583862445, "cent trente-neuf milliards cinq cent quatre-vingt-trois millions huit cent soixante-deux mille quatre cent quarante-cinq")
  , (225851433717, "deux cent vingt-cinq milliards huit cent cinquante et un millions quatre cent trente-trois mille sept cent dix-sept")
  , (365435296162, "trois cent soixante-cinq milliards quatre cent trente-cinq millions deux cent quatre-vingt-seize mille cent soixante-deux")
  , (591286729879, "cinq cent quatre-vingt-onze milliards deux cent quatre-vingt-six millions sept cent vingt-neuf mille huit cent soixante-dix-neuf")
  , (956722026041, "neuf cent cinquante-six milliards sept cent vingt-deux millions vingt-six mille quarante et un")
  , (1548008755920, "un billion cinq cent quarante-huit milliards huit millions sept cent cinquante-cinq mille neuf cent vingt")
  , (2504730781961, "deux billions cinq cent quatre milliards sept cent trente millions sept cent quatre-vingt-un mille neuf cent soixante et un")
  , (4052739537881, "quatre billions cinquante-deux milliards sept cent trente-neuf millions cinq cent trente-sept mille huit cent quatre-vingt-un")
  , (6557470319842, "six billions cinq cent cinquante-sept milliards quatre cent soixante-dix millions trois cent dix-neuf mille huit cent quarante-deux")
  , (10610209857723, "dix billions six cent dix milliards deux cent neuf millions huit cent cinquante-sept mille sept cent vingt-trois")
  , (17167680177565, "dix-sept billions cent soixante-sept milliards six cent quatre-vingts millions cent soixante-dix-sept mille cinq cent soixante-cinq")
  , (27777890035288, "vingt-sept billions sept cent soixante-dix-sept milliards huit cent quatre-vingt-dix millions trente-cinq mille deux cent quatre-vingt-huit")
  , (44945570212853, "quarante-quatre billions neuf cent quarante-cinq milliards cinq cent soixante-dix millions deux cent douze mille huit cent cinquante-trois")
  , (72723460248141, "soixante-douze billions sept cent vingt-trois milliards quatre cent soixante millions deux cent quarante-huit mille cent quarante et un")
  , (117669030460994, "cent dix-sept billions six cent soixante-neuf milliards trente millions quatre cent soixante mille neuf cent quatre-vingt-quatorze")
  , (190392490709135, "cent quatre-vingt-dix billions trois cent quatre-vingt-douze milliards quatre cent quatre-vingt-dix millions sept cent neuf mille cent trente-cinq")
  , (308061521170129, "trois cent huit billions soixante et un milliards cinq cent vingt et un millions cent soixante-dix mille cent vingt-neuf")
  , (498454011879264, "quatre cent quatre-vingt-dix-huit billions quatre cent cinquante-quatre milliards onze millions huit cent soixante-dix-neuf mille deux cent soixante-quatre")
  , (806515533049393, "huit cent six billions cinq cent quinze milliards cinq cent trente-trois millions quarante-neuf mille trois cent quatre-vingt-treize")
  , (1304969544928657, "un billiard trois cent quatre billions neuf cent soixante-neuf milliards cinq cent quarante-quatre millions neuf cent vingt-huit mille six cent cinquante-sept")
  , (2111485077978050, "deux billiards cent onze billions quatre cent quatre-vingt-cinq milliards soixante-dix-sept millions neuf cent soixante-dix-huit mille cinquante")
  , (3416454622906707, "trois billiards quatre cent seize billions quatre cent cinquante-quatre milliards six cent vingt-deux millions neuf cent six mille sept cent sept")
  , (5527939700884757, "cinq billiards cinq cent vingt-sept billions neuf cent trente-neuf milliards sept cents millions huit cent quatre-vingt-quatre mille sept cent cinquante-sept")
  , (8944394323791464, "huit billiards neuf cent quarante-quatre billions trois cent quatre-vingt-quatorze milliards trois cent vingt-trois millions sept cent quatre-vingt-onze mille quatre cent soixante-quatre")
  , (14472334024676221, "quatorze billiards quatre cent soixante-douze billions trois cent trente-quatre milliards vingt-quatre millions six cent soixante-seize mille deux cent vingt et un")
  , (23416728348467685, "vingt-trois billiards quatre cent seize billions sept cent vingt-huit milliards trois cent quarante-huit millions quatre cent soixante-sept mille six cent quatre-vingt-cinq")
  , (37889062373143906, "trente-sept billiards huit cent quatre-vingt-neuf billions soixante-deux milliards trois cent soixante-treize millions cent quarante-trois mille neuf cent six")
  , (61305790721611591, "soixante et un billiards trois cent cinq billions sept cent quatre-vingt-dix milliards sept cent vingt et un millions six cent onze mille cinq cent quatre-vingt-onze")
  , (99194853094755497, "quatre-vingt-dix-neuf billiards cent quatre-vingt-quatorze billions huit cent cinquante-trois milliards quatre-vingt-quatorze millions sept cent cinquante-cinq mille quatre cent quatre-vingt-dix-sept")
  , (160500643816367088, "cent soixante billiards cinq cents billions six cent quarante-trois milliards huit cent seize millions trois cent soixante-sept mille quatre-vingt-huit")
  , (259695496911122585, "deux cent cinquante-neuf billiards six cent quatre-vingt-quinze billions quatre cent quatre-vingt-seize milliards neuf cent onze millions cent vingt-deux mille cinq cent quatre-vingt-cinq")
  , (420196140727489673, "quatre cent vingt billiards cent quatre-vingt-seize billions cent quarante milliards sept cent vingt-sept millions quatre cent quatre-vingt-neuf mille six cent soixante-treize")
  , (679891637638612258, "six cent soixante-dix-neuf billiards huit cent quatre-vingt-onze billions six cent trente-sept milliards six cent trente-huit millions six cent douze mille deux cent cinquante-huit")
  , (1100087778366101931, "un trillion cent billiards quatre-vingt-sept billions sept cent soixante-dix-huit milliards trois cent soixante-six millions cent un mille neuf cent trente et un")
  , (1779979416004714189, "un trillion sept cent soixante-dix-neuf billiards neuf cent soixante-dix-neuf billions quatre cent seize milliards quatre millions sept cent quatorze mille cent quatre-vingt-neuf")
  , (2880067194370816120, "deux trillions huit cent quatre-vingts billiards soixante-sept billions cent quatre-vingt-quatorze milliards trois cent soixante-dix millions huit cent seize mille cent vingt")
  , (4660046610375530309, "quatre trillions six cent soixante billiards quarante-six billions six cent dix milliards trois cent soixante-quinze millions cinq cent trente mille trois cent neuf")
  , (7540113804746346429, "sept trillions cinq cent quarante billiards cent treize billions huit cent quatre milliards sept cent quarante-six millions trois cent quarante-six mille quatre cent vingt-neuf")
  , (12200160415121876738, "douze trillions deux cents billiards cent soixante billions quatre cent quinze milliards cent vingt et un millions huit cent soixante-seize mille sept cent trente-huit")
  , (19740274219868223167, "dix-neuf trillions sept cent quarante billiards deux cent soixante-quatorze billions deux cent dix-neuf milliards huit cent soixante-huit millions deux cent vingt-trois mille cent soixante-sept")
  , (31940434634990099905, "trente et un trillions neuf cent quarante billiards quatre cent trente-quatre billions six cent trente-quatre milliards neuf cent quatre-vingt-dix millions quatre-vingt-dix-neuf mille neuf cent cinq")
  , (51680708854858323072, "cinquante et un trillions six cent quatre-vingts billiards sept cent huit billions huit cent cinquante-quatre milliards huit cent cinquante-huit millions trois cent vingt-trois mille soixante-douze")
  , (83621143489848422977, "quatre-vingt-trois trillions six cent vingt et un billiards cent quarante-trois billions quatre cent quatre-vingt-neuf milliards huit cent quarante-huit millions quatre cent vingt-deux mille neuf cent soixante-dix-sept")
  , (135301852344706746049, "cent trente-cinq trillions trois cent un billiards huit cent cinquante-deux billions trois cent quarante-quatre milliards sept cent six millions sept cent quarante-six mille quarante-neuf")
  , (218922995834555169026, "deux cent dix-huit trillions neuf cent vingt-deux billiards neuf cent quatre-vingt-quinze billions huit cent trente-quatre milliards cinq cent cinquante-cinq millions cent soixante-neuf mille vingt-six")
  , (354224848179261915075, "trois cent cinquante-quatre trillions deux cent vingt-quatre billiards huit cent quarante-huit billions cent soixante-dix-neuf milliards deux cent soixante et un millions neuf cent quinze mille soixante-quinze")
  , (573147844013817084101, "cinq cent soixante-treize trillions cent quarante-sept billiards huit cent quarante-quatre billions treize milliards huit cent dix-sept millions quatre-vingt-quatre mille cent un")
  , (927372692193078999176, "neuf cent vingt-sept trillions trois cent soixante-douze billiards six cent quatre-vingt-douze billions cent quatre-vingt-treize milliards soixante-dix-huit millions neuf cent quatre-vingt-dix-neuf mille cent soixante-seize")
  , (1500520536206896083277, "un trilliard cinq cents trillions cinq cent vingt billiards cinq cent trente-six billions deux cent six milliards huit cent quatre-vingt-seize millions quatre-vingt-trois mille deux cent soixante-dix-sept")
  , (2427893228399975082453, "deux trilliards quatre cent vingt-sept trillions huit cent quatre-vingt-treize billiards deux cent vingt-huit billions trois cent quatre-vingt-dix-neuf milliards neuf cent soixante-quinze millions quatre-vingt-deux mille quatre cent cinquante-trois")
  , (3928413764606871165730, "trois trilliards neuf cent vingt-huit trillions quatre cent treize billiards sept cent soixante-quatre billions six cent six milliards huit cent soixante et onze millions cent soixante-cinq mille sept cent trente")
  , (6356306993006846248183, "six trilliards trois cent cinquante-six trillions trois cent six billiards neuf cent quatre-vingt-treize billions six milliards huit cent quarante-six millions deux cent quarante-huit mille cent quatre-vingt-trois")
  , (10284720757613717413913, "dix trilliards deux cent quatre-vingt-quatre trillions sept cent vingt billiards sept cent cinquante-sept billions six cent treize milliards sept cent dix-sept millions quatre cent treize mille neuf cent treize")
  , (16641027750620563662096, "seize trilliards six cent quarante et un trillions vingt-sept billiards sept cent cinquante billions six cent vingt milliards cinq cent soixante-trois millions six cent soixante-deux mille quatre-vingt-seize")
  , (26925748508234281076009, "vingt-six trilliards neuf cent vingt-cinq trillions sept cent quarante-huit billiards cinq cent huit billions deux cent trente-quatre milliards deux cent quatre-vingt-un millions soixante-seize mille neuf")
  , (43566776258854844738105, "quarante-trois trilliards cinq cent soixante-six trillions sept cent soixante-seize billiards deux cent cinquante-huit billions huit cent cinquante-quatre milliards huit cent quarante-quatre millions sept cent trente-huit mille cent cinq")
  , (70492524767089125814114, "soixante-dix trilliards quatre cent quatre-vingt-douze trillions cinq cent vingt-quatre billiards sept cent soixante-sept billions quatre-vingt-neuf milliards cent vingt-cinq millions huit cent quatorze mille cent quatorze")
  , (114059301025943970552219, "cent quatorze trilliards cinquante-neuf trillions trois cent un billiards vingt-cinq billions neuf cent quarante-trois milliards neuf cent soixante-dix millions cinq cent cinquante-deux mille deux cent dix-neuf")
  , (1000, "mille")
  , (10000, "dix mille")
  , (100000, "cent mille")
  , (1000000, "un million")
  , (10000000, "dix millions")
  , (100000000, "cent millions")
  , (1000000000, "un milliard")
  , (10000000000, "dix milliards")
  , (100000000000, "cent milliards")
  , (1000000000000, "un billion")
  , (10000000000000, "dix billions")
  , (100000000000000, "cent billions")
  , (1000000000000000, "un billiard")
  , (10000000000000000, "dix billiards")
  , (100000000000000000, "cent billiards")
  , (1000000000000000000, "un trillion")
  , (10000000000000000000, "dix trillions")
  , (100000000000000000000, "cent trillions")
  , (1000000000000000000000, "un trilliard")
  , (10000000000000000000000, "dix trilliards")
  , (100000000000000000000000, "cent trilliards")
  , (1000000000000000000000000, "un quadrillion")
  ]

ordinals :: [(Integer, Text)]
ordinals = [
    (0, "zéroième")
  , (1, "premier")
  , (2, "deuxième")
  , (3, "troisième")
  , (4, "quatrième")
  , (5, "cinquième")
  , (6, "sixième")
  , (7, "septième")
  , (8, "huitième")
  , (9, "neuvième")
  , (10, "dixième")
  , (11, "onzième")
  , (12, "douzième")
  , (13, "treizième")
  , (14, "quatorzième")
  , (15, "quinzième")
  , (16, "seizième")
  , (17, "dix-septième")
  , (18, "dix-huitième")
  , (19, "dix-neuvième")
  , (20, "vingtième")
  , (21, "vingt et unième")
  , (22, "vingt-deuxième")
  , (23, "vingt-troisième")
  , (24, "vingt-quatrième")
  , (25, "vingt-cinquième")
  , (26, "vingt-sixième")
  , (27, "vingt-septième")
  , (28, "vingt-huitième")
  , (29, "vingt-neuvième")
  , (30, "trentième")
  , (31, "trente et unième")
  , (32, "trente-deuxième")
  , (33, "trente-troisième")
  , (34, "trente-quatrième")
  , (35, "trente-cinquième")
  , (36, "trente-sixième")
  , (37, "trente-septième")
  , (38, "trente-huitième")
  , (39, "trente-neuvième")
  , (40, "quarantième")
  , (41, "quarante et unième")
  , (42, "quarante-deuxième")
  , (43, "quarante-troisième")
  , (44, "quarante-quatrième")
  , (45, "quarante-cinquième")
  , (46, "quarante-sixième")
  , (47, "quarante-septième")
  , (48, "quarante-huitième")
  , (49, "quarante-neuvième")
  , (50, "cinquantième")
  , (51, "cinquante et unième")
  , (52, "cinquante-deuxième")
  , (53, "cinquante-troisième")
  , (54, "cinquante-quatrième")
  , (55, "cinquante-cinquième")
  , (56, "cinquante-sixième")
  , (57, "cinquante-septième")
  , (58, "cinquante-huitième")
  , (59, "cinquante-neuvième")
  , (60, "soixantième")
  , (61, "soixante et unième")
  , (62, "soixante-deuxième")
  , (63, "soixante-troisième")
  , (64, "soixante-quatrième")
  , (65, "soixante-cinquième")
  , (66, "soixante-sixième")
  , (67, "soixante-septième")
  , (68, "soixante-huitième")
  , (69, "soixante-neuvième")
  , (70, "soixante-dixième")
  , (71, "soixante et onzième")
  , (72, "soixante-douzième")
  , (73, "soixante-treizième")
  , (74, "soixante-quatorzième")
  , (75, "soixante-quinzième")
  , (76, "soixante-seizième")
  , (77, "soixante-dix-septième")
  , (78, "soixante-dix-huitième")
  , (79, "soixante-dix-neuvième")
  , (80, "quatre-vingtsième")
  , (81, "quatre-vingt-unième")
  , (82, "quatre-vingt-deuxième")
  , (83, "quatre-vingt-troisième")
  , (84, "quatre-vingt-quatrième")
  , (85, "quatre-vingt-cinquième")
  , (86, "quatre-vingt-sixième")
  , (87, "quatre-vingt-septième")
  , (88, "quatre-vingt-huitième")
  , (89, "quatre-vingt-neuvième")
  , (90, "quatre-vingt-dixième")
  , (91, "quatre-vingt-onzième")
  , (92, "quatre-vingt-douzième")
  , (93, "quatre-vingt-treizième")
  , (94, "quatre-vingt-quatorzième")
  , (95, "quatre-vingt-quinzième")
  , (96, "quatre-vingt-seizième")
  , (97, "quatre-vingt-dix-septième")
  , (98, "quatre-vingt-dix-huitième")
  , (99, "quatre-vingt-dix-neuvième")
  , (100, "centième")
  , (101, "cent unième")
  , (102, "cent deuxième")
  , (103, "cent troisième")
  , (104, "cent quatrième")
  , (105, "cent cinquième")
  , (106, "cent sixième")
  , (107, "cent septième")
  , (108, "cent huitième")
  , (109, "cent neuvième")
  , (110, "cent dixième")
  , (111, "cent onzième")
  , (112, "cent douzième")
  , (113, "cent treizième")
  , (114, "cent quatorzième")
  , (115, "cent quinzième")
  , (116, "cent seizième")
  , (117, "cent dix-septième")
  , (118, "cent dix-huitième")
  , (119, "cent dix-neuvième")
  , (120, "cent vingtième")
  , (121, "cent vingt et unième")
  , (122, "cent vingt-deuxième")
  , (123, "cent vingt-troisième")
  , (124, "cent vingt-quatrième")
  , (125, "cent vingt-cinquième")
  , (126, "cent vingt-sixième")
  , (127, "cent vingt-septième")
  , (128, "cent vingt-huitième")
  , (129, "cent vingt-neuvième")
  , (130, "cent trentième")
  , (131, "cent trente et unième")
  , (132, "cent trente-deuxième")
  , (133, "cent trente-troisième")
  , (134, "cent trente-quatrième")
  , (135, "cent trente-cinquième")
  , (136, "cent trente-sixième")
  , (137, "cent trente-septième")
  , (138, "cent trente-huitième")
  , (139, "cent trente-neuvième")
  , (140, "cent quarantième")
  , (141, "cent quarante et unième")
  , (142, "cent quarante-deuxième")
  , (143, "cent quarante-troisième")
  , (144, "cent quarante-quatrième")
  , (145, "cent quarante-cinquième")
  , (146, "cent quarante-sixième")
  , (147, "cent quarante-septième")
  , (148, "cent quarante-huitième")
  , (149, "cent quarante-neuvième")
  , (150, "cent cinquantième")
  , (151, "cent cinquante et unième")
  , (152, "cent cinquante-deuxième")
  , (153, "cent cinquante-troisième")
  , (154, "cent cinquante-quatrième")
  , (155, "cent cinquante-cinquième")
  , (156, "cent cinquante-sixième")
  , (157, "cent cinquante-septième")
  , (158, "cent cinquante-huitième")
  , (159, "cent cinquante-neuvième")
  , (160, "cent soixantième")
  , (161, "cent soixante et unième")
  , (162, "cent soixante-deuxième")
  , (163, "cent soixante-troisième")
  , (164, "cent soixante-quatrième")
  , (165, "cent soixante-cinquième")
  , (166, "cent soixante-sixième")
  , (167, "cent soixante-septième")
  , (168, "cent soixante-huitième")
  , (169, "cent soixante-neuvième")
  , (170, "cent soixante-dixième")
  , (171, "cent soixante et onzième")
  , (172, "cent soixante-douzième")
  , (173, "cent soixante-treizième")
  , (174, "cent soixante-quatorzième")
  , (175, "cent soixante-quinzième")
  , (176, "cent soixante-seizième")
  , (177, "cent soixante-dix-septième")
  , (178, "cent soixante-dix-huitième")
  , (179, "cent soixante-dix-neuvième")
  , (180, "cent quatre-vingtsième")
  , (181, "cent quatre-vingt-unième")
  , (182, "cent quatre-vingt-deuxième")
  , (183, "cent quatre-vingt-troisième")
  , (184, "cent quatre-vingt-quatrième")
  , (185, "cent quatre-vingt-cinquième")
  , (186, "cent quatre-vingt-sixième")
  , (187, "cent quatre-vingt-septième")
  , (188, "cent quatre-vingt-huitième")
  , (189, "cent quatre-vingt-neuvième")
  , (190, "cent quatre-vingt-dixième")
  , (191, "cent quatre-vingt-onzième")
  , (192, "cent quatre-vingt-douzième")
  , (193, "cent quatre-vingt-treizième")
  , (194, "cent quatre-vingt-quatorzième")
  , (195, "cent quatre-vingt-quinzième")
  , (196, "cent quatre-vingt-seizième")
  , (197, "cent quatre-vingt-dix-septième")
  , (198, "cent quatre-vingt-dix-huitième")
  , (199, "cent quatre-vingt-dix-neuvième")
  , (200, "deux centsième")
  , (233, "deux cent trente-troisième")
  , (377, "trois cent soixante-dix-septième")
  , (610, "six cent dixième")
  , (987, "neuf cent quatre-vingt-septième")
  , (1597, "mille cinq cent quatre-vingt-dix-septième")
  , (2584, "deux mille cinq cent quatre-vingt-quatrième")
  , (4181, "quatre mille cent quatre-vingt-unième")
  , (6765, "six mille sept cent soixante-cinquième")
  , (10946, "dix mille neuf cent quarante-sixième")
  , (17711, "dix-sept mille sept cent onzième")
  , (28657, "vingt-huit mille six cent cinquante-septième")
  , (46368, "quarante-six mille trois cent soixante-huitième")
  , (75025, "soixante-quinze mille vingt-cinquième")
  , (121393, "cent vingt et un mille trois cent quatre-vingt-treizième")
  , (196418, "cent quatre-vingt-seize mille quatre cent dix-huitième")
  , (317811, "trois cent dix-sept mille huit cent onzième")
  , (514229, "cinq cent quatorze mille deux cent vingt-neuvième")
  , (832040, "huit cent trente-deux mille quarantième")
  , (1346269, "un million trois cent quarante-six mille deux cent soixante-neuvième")
  , (2178309, "deux millions cent soixante-dix-huit mille trois cent neuvième")
  , (3524578, "trois millions cinq cent vingt-quatre mille cinq cent soixante-dix-huitième")
  , (5702887, "cinq millions sept cent deux mille huit cent quatre-vingt-septième")
  , (9227465, "neuf millions deux cent vingt-sept mille quatre cent soixante-cinquième")
  , (14930352, "quatorze millions neuf cent trente mille trois cent cinquante-deuxième")
  , (24157817, "vingt-quatre millions cent cinquante-sept mille huit cent dix-septième")
  , (39088169, "trente-neuf millions quatre-vingt-huit mille cent soixante-neuvième")
  , (63245986, "soixante-trois millions deux cent quarante-cinq mille neuf cent quatre-vingt-sixième")
  , (102334155, "cent deux millions trois cent trente-quatre mille cent cinquante-cinquième")
  , (165580141, "cent soixante-cinq millions cinq cent quatre-vingt mille cent quarante et unième")
  , (267914296, "deux cent soixante-sept millions neuf cent quatorze mille deux cent quatre-vingt-seizième")
  , (433494437, "quatre cent trente-trois millions quatre cent quatre-vingt-quatorze mille quatre cent trente-septième")
  , (701408733, "sept cent un millions quatre cent huit mille sept cent trente-troisième")
  , (1134903170, "un milliard cent trente-quatre millions neuf cent trois mille cent soixante-dixième")
  , (1836311903, "un milliard huit cent trente-six millions trois cent onze mille neuf cent troisième")
  , (2971215073, "deux milliards neuf cent soixante et onze millions deux cent quinze mille soixante-treizième")
  , (4807526976, "quatre milliards huit cent sept millions cinq cent vingt-six mille neuf cent soixante-seizième")
  , (7778742049, "sept milliards sept cent soixante-dix-huit millions sept cent quarante-deux mille quarante-neuvième")
  , (12586269025, "douze milliards cinq cent quatre-vingt-six millions deux cent soixante-neuf mille vingt-cinquième")
  , (20365011074, "vingt milliards trois cent soixante-cinq millions onze mille soixante-quatorzième")
  , (32951280099, "trente-deux milliards neuf cent cinquante et un millions deux cent quatre-vingt mille quatre-vingt-dix-neuvième")
  , (53316291173, "cinquante-trois milliards trois cent seize millions deux cent quatre-vingt-onze mille cent soixante-treizième")
  , (86267571272, "quatre-vingt-six milliards deux cent soixante-sept millions cinq cent soixante et onze mille deux cent soixante-douzième")
  , (139583862445, "cent trente-neuf milliards cinq cent quatre-vingt-trois millions huit cent soixante-deux mille quatre cent quarante-cinquième")
  , (225851433717, "deux cent vingt-cinq milliards huit cent cinquante et un millions quatre cent trente-trois mille sept cent dix-septième")
  , (365435296162, "trois cent soixante-cinq milliards quatre cent trente-cinq millions deux cent quatre-vingt-seize mille cent soixante-deuxième")
  , (591286729879, "cinq cent quatre-vingt-onze milliards deux cent quatre-vingt-six millions sept cent vingt-neuf mille huit cent soixante-dix-neuvième")
  , (956722026041, "neuf cent cinquante-six milliards sept cent vingt-deux millions vingt-six mille quarante et unième")
  , (1548008755920, "un billion cinq cent quarante-huit milliards huit millions sept cent cinquante-cinq mille neuf cent vingtième")
  , (2504730781961, "deux billions cinq cent quatre milliards sept cent trente millions sept cent quatre-vingt-un mille neuf cent soixante et unième")
  , (4052739537881, "quatre billions cinquante-deux milliards sept cent trente-neuf millions cinq cent trente-sept mille huit cent quatre-vingt-unième")
  , (6557470319842, "six billions cinq cent cinquante-sept milliards quatre cent soixante-dix millions trois cent dix-neuf mille huit cent quarante-deuxième")
  , (10610209857723, "dix billions six cent dix milliards deux cent neuf millions huit cent cinquante-sept mille sept cent vingt-troisième")
  , (17167680177565, "dix-sept billions cent soixante-sept milliards six cent quatre-vingts millions cent soixante-dix-sept mille cinq cent soixante-cinquième")
  , (27777890035288, "vingt-sept billions sept cent soixante-dix-sept milliards huit cent quatre-vingt-dix millions trente-cinq mille deux cent quatre-vingt-huitième")
  , (44945570212853, "quarante-quatre billions neuf cent quarante-cinq milliards cinq cent soixante-dix millions deux cent douze mille huit cent cinquante-troisième")
  , (72723460248141, "soixante-douze billions sept cent vingt-trois milliards quatre cent soixante millions deux cent quarante-huit mille cent quarante et unième")
  , (117669030460994, "cent dix-sept billions six cent soixante-neuf milliards trente millions quatre cent soixante mille neuf cent quatre-vingt-quatorzième")
  , (190392490709135, "cent quatre-vingt-dix billions trois cent quatre-vingt-douze milliards quatre cent quatre-vingt-dix millions sept cent neuf mille cent trente-cinquième")
  , (308061521170129, "trois cent huit billions soixante et un milliards cinq cent vingt et un millions cent soixante-dix mille cent vingt-neuvième")
  , (498454011879264, "quatre cent quatre-vingt-dix-huit billions quatre cent cinquante-quatre milliards onze millions huit cent soixante-dix-neuf mille deux cent soixante-quatrième")
  , (806515533049393, "huit cent six billions cinq cent quinze milliards cinq cent trente-trois millions quarante-neuf mille trois cent quatre-vingt-treizième")
  , (1304969544928657, "un billiard trois cent quatre billions neuf cent soixante-neuf milliards cinq cent quarante-quatre millions neuf cent vingt-huit mille six cent cinquante-septième")
  , (2111485077978050, "deux billiards cent onze billions quatre cent quatre-vingt-cinq milliards soixante-dix-sept millions neuf cent soixante-dix-huit mille cinquantième")
  , (3416454622906707, "trois billiards quatre cent seize billions quatre cent cinquante-quatre milliards six cent vingt-deux millions neuf cent six mille sept cent septième")
  , (5527939700884757, "cinq billiards cinq cent vingt-sept billions neuf cent trente-neuf milliards sept cents millions huit cent quatre-vingt-quatre mille sept cent cinquante-septième")
  , (8944394323791464, "huit billiards neuf cent quarante-quatre billions trois cent quatre-vingt-quatorze milliards trois cent vingt-trois millions sept cent quatre-vingt-onze mille quatre cent soixante-quatrième")
  , (14472334024676221, "quatorze billiards quatre cent soixante-douze billions trois cent trente-quatre milliards vingt-quatre millions six cent soixante-seize mille deux cent vingt et unième")
  , (23416728348467685, "vingt-trois billiards quatre cent seize billions sept cent vingt-huit milliards trois cent quarante-huit millions quatre cent soixante-sept mille six cent quatre-vingt-cinquième")
  , (37889062373143906, "trente-sept billiards huit cent quatre-vingt-neuf billions soixante-deux milliards trois cent soixante-treize millions cent quarante-trois mille neuf cent sixième")
  , (61305790721611591, "soixante et un billiards trois cent cinq billions sept cent quatre-vingt-dix milliards sept cent vingt et un millions six cent onze mille cinq cent quatre-vingt-onzième")
  , (99194853094755497, "quatre-vingt-dix-neuf billiards cent quatre-vingt-quatorze billions huit cent cinquante-trois milliards quatre-vingt-quatorze millions sept cent cinquante-cinq mille quatre cent quatre-vingt-dix-septième")
  , (160500643816367088, "cent soixante billiards cinq cents billions six cent quarante-trois milliards huit cent seize millions trois cent soixante-sept mille quatre-vingt-huitième")
  , (259695496911122585, "deux cent cinquante-neuf billiards six cent quatre-vingt-quinze billions quatre cent quatre-vingt-seize milliards neuf cent onze millions cent vingt-deux mille cinq cent quatre-vingt-cinquième")
  , (420196140727489673, "quatre cent vingt billiards cent quatre-vingt-seize billions cent quarante milliards sept cent vingt-sept millions quatre cent quatre-vingt-neuf mille six cent soixante-treizième")
  , (679891637638612258, "six cent soixante-dix-neuf billiards huit cent quatre-vingt-onze billions six cent trente-sept milliards six cent trente-huit millions six cent douze mille deux cent cinquante-huitième")
  , (1100087778366101931, "un trillion cent billiards quatre-vingt-sept billions sept cent soixante-dix-huit milliards trois cent soixante-six millions cent un mille neuf cent trente et unième")
  , (1779979416004714189, "un trillion sept cent soixante-dix-neuf billiards neuf cent soixante-dix-neuf billions quatre cent seize milliards quatre millions sept cent quatorze mille cent quatre-vingt-neuvième")
  , (2880067194370816120, "deux trillions huit cent quatre-vingts billiards soixante-sept billions cent quatre-vingt-quatorze milliards trois cent soixante-dix millions huit cent seize mille cent vingtième")
  , (4660046610375530309, "quatre trillions six cent soixante billiards quarante-six billions six cent dix milliards trois cent soixante-quinze millions cinq cent trente mille trois cent neuvième")
  , (7540113804746346429, "sept trillions cinq cent quarante billiards cent treize billions huit cent quatre milliards sept cent quarante-six millions trois cent quarante-six mille quatre cent vingt-neuvième")
  , (12200160415121876738, "douze trillions deux cents billiards cent soixante billions quatre cent quinze milliards cent vingt et un millions huit cent soixante-seize mille sept cent trente-huitième")
  , (19740274219868223167, "dix-neuf trillions sept cent quarante billiards deux cent soixante-quatorze billions deux cent dix-neuf milliards huit cent soixante-huit millions deux cent vingt-trois mille cent soixante-septième")
  , (31940434634990099905, "trente et un trillions neuf cent quarante billiards quatre cent trente-quatre billions six cent trente-quatre milliards neuf cent quatre-vingt-dix millions quatre-vingt-dix-neuf mille neuf cent cinquième")
  , (51680708854858323072, "cinquante et un trillions six cent quatre-vingts billiards sept cent huit billions huit cent cinquante-quatre milliards huit cent cinquante-huit millions trois cent vingt-trois mille soixante-douzième")
  , (83621143489848422977, "quatre-vingt-trois trillions six cent vingt et un billiards cent quarante-trois billions quatre cent quatre-vingt-neuf milliards huit cent quarante-huit millions quatre cent vingt-deux mille neuf cent soixante-dix-septième")
  , (135301852344706746049, "cent trente-cinq trillions trois cent un billiards huit cent cinquante-deux billions trois cent quarante-quatre milliards sept cent six millions sept cent quarante-six mille quarante-neuvième")
  , (218922995834555169026, "deux cent dix-huit trillions neuf cent vingt-deux billiards neuf cent quatre-vingt-quinze billions huit cent trente-quatre milliards cinq cent cinquante-cinq millions cent soixante-neuf mille vingt-sixième")
  , (354224848179261915075, "trois cent cinquante-quatre trillions deux cent vingt-quatre billiards huit cent quarante-huit billions cent soixante-dix-neuf milliards deux cent soixante et un millions neuf cent quinze mille soixante-quinzième")
  , (573147844013817084101, "cinq cent soixante-treize trillions cent quarante-sept billiards huit cent quarante-quatre billions treize milliards huit cent dix-sept millions quatre-vingt-quatre mille cent unième")
  , (927372692193078999176, "neuf cent vingt-sept trillions trois cent soixante-douze billiards six cent quatre-vingt-douze billions cent quatre-vingt-treize milliards soixante-dix-huit millions neuf cent quatre-vingt-dix-neuf mille cent soixante-seizième")
  , (1500520536206896083277, "un trilliard cinq cents trillions cinq cent vingt billiards cinq cent trente-six billions deux cent six milliards huit cent quatre-vingt-seize millions quatre-vingt-trois mille deux cent soixante-dix-septième")
  , (2427893228399975082453, "deux trilliards quatre cent vingt-sept trillions huit cent quatre-vingt-treize billiards deux cent vingt-huit billions trois cent quatre-vingt-dix-neuf milliards neuf cent soixante-quinze millions quatre-vingt-deux mille quatre cent cinquante-troisième")
  , (3928413764606871165730, "trois trilliards neuf cent vingt-huit trillions quatre cent treize billiards sept cent soixante-quatre billions six cent six milliards huit cent soixante et onze millions cent soixante-cinq mille sept cent trentième")
  , (6356306993006846248183, "six trilliards trois cent cinquante-six trillions trois cent six billiards neuf cent quatre-vingt-treize billions six milliards huit cent quarante-six millions deux cent quarante-huit mille cent quatre-vingt-troisième")
  , (10284720757613717413913, "dix trilliards deux cent quatre-vingt-quatre trillions sept cent vingt billiards sept cent cinquante-sept billions six cent treize milliards sept cent dix-sept millions quatre cent treize mille neuf cent treizième")
  , (16641027750620563662096, "seize trilliards six cent quarante et un trillions vingt-sept billiards sept cent cinquante billions six cent vingt milliards cinq cent soixante-trois millions six cent soixante-deux mille quatre-vingt-seizième")
  , (26925748508234281076009, "vingt-six trilliards neuf cent vingt-cinq trillions sept cent quarante-huit billiards cinq cent huit billions deux cent trente-quatre milliards deux cent quatre-vingt-un millions soixante-seize mille neuvième")
  , (43566776258854844738105, "quarante-trois trilliards cinq cent soixante-six trillions sept cent soixante-seize billiards deux cent cinquante-huit billions huit cent cinquante-quatre milliards huit cent quarante-quatre millions sept cent trente-huit mille cent cinquième")
  , (70492524767089125814114, "soixante-dix trilliards quatre cent quatre-vingt-douze trillions cinq cent vingt-quatre billiards sept cent soixante-sept billions quatre-vingt-neuf milliards cent vingt-cinq millions huit cent quatorze mille cent quatorzième")
  , (114059301025943970552219, "cent quatorze trilliards cinquante-neuf trillions trois cent un billiards vingt-cinq billions neuf cent quarante-trois milliards neuf cent soixante-dix millions cinq cent cinquante-deux mille deux cent dix-neuvième")
  , (1000, "millième")
  , (10000, "dix millième")
  , (100000, "cent millième")
  , (1000000, "un millionième")
  , (10000000, "dix millionsième")
  , (100000000, "cent millionsième")
  , (1000000000, "un milliardième")
  , (10000000000, "dix milliardsième")
  , (100000000000, "cent milliardsième")
  , (1000000000000, "un billionième")
  , (10000000000000, "dix billionsième")
  , (100000000000000, "cent billionsième")
  , (1000000000000000, "un billiardième")
  , (10000000000000000, "dix billiardsième")
  , (100000000000000000, "cent billiardsième")
  , (1000000000000000000, "un trillionième")
  , (10000000000000000000, "dix trillionsième")
  , (100000000000000000000, "cent trillionsième")
  , (1000000000000000000000, "un trilliardième")
  , (10000000000000000000000, "dix trilliardsième")
  , (100000000000000000000000, "cent trilliardsième")
  , (1000000000000000000000000, "un quadrillionième")
  ]
